# Individual Contributor License Agreement (ICLA)

Thank you for your interest in contributing to this project.

This Contributor License Agreement ("Agreement") is entered into between
you ("Contributor") and the project owner ("Project").

## 1. Grant of Copyright License

You hereby grant to the Project a perpetual, worldwide, non-exclusive,
no-charge, royalty-free, irrevocable copyright license to reproduce,
prepare derivative works of, publicly display, publicly perform,
sublicense, and distribute your contributions and such derivative works.

## 2. Grant of Patent License

You hereby grant to the Project a perpetual, worldwide, non-exclusive,
no-charge, royalty-free, irrevocable patent license to make, have made,
use, offer to sell, sell, import, and otherwise transfer your
contributions, where such license applies only to those patent claims
necessarily infringed by your contribution.

## 3. Authority

You represent that you are legally entitled to grant the above licenses.
If your employer has rights to intellectual property that you create,
you represent that you have received permission to make contributions
on behalf of that employer.

## 4. No Warranty

You provide your contributions on an "AS IS" basis, without warranties
or conditions of any kind.

---

By submitting a contribution, you agree to the terms of this Agreement.